@@ -293,7 +293,7 @@ class Client(object):
 
         Args:
           server: tuple(hostname, port) or string containing a UNIX socket path.
-          serde: optional seralizer object, see notes in the class docs.
+          serde: optional serializer object, see notes in the class docs.
           serializer: deprecated serialization function
           deserializer: deprecated deserialization function
           connect_timeout: optional float, seconds to wait for a connection to
@@ -1038,7 +1038,7 @@ class Client(object):
                     result[key] = value
                 elif name == b'stats' and line.startswith(b'STAT'):
                     key_value = line.split()
-                    result[key_value[1]] = key_value[2]
+                    result[key_value[1]] = key_value[2] if len(key_value) > 2 else b""
                 elif name == b'stats' and line.startswith(b'ITEM'):
                     # For 'stats cachedump' commands
                     key_value = line.split()
@@ -1287,7 +1287,7 @@ class PooledClient(object):
                 return client.get(key, default)
             except Exception:
                 if self.ignore_exc:
-                    return None
+                    return default
                 else:
                     raise
 
