@@ -1,5 +1,7 @@
+import os.path
 import pytest
 import socket
+import ssl
 
 
 def pytest_addoption(parser):
@@ -9,6 +11,12 @@ def pytest_addoption(parser):
     parser.addoption('--port', action='store', default='11211',
                      help='memcached server port')
 
+    parser.addoption('--tls-server', action='store', default='localhost',
+                     help='TLS memcached server')
+
+    parser.addoption('--tls-port', action='store', default='11212',
+                     help='TLS memcached server port')
+
     parser.addoption('--size', action='store', default=1024,
                      help='size of data in benchmarks')
 
@@ -29,6 +37,16 @@ def port(request):
     return int(request.config.option.port)
 
 
+@pytest.fixture(scope='session')
+def tls_host(request):
+    return request.config.option.tls_server
+
+
+@pytest.fixture(scope='session')
+def tls_port(request):
+    return int(request.config.option.tls_port)
+
+
 @pytest.fixture(scope='session')
 def size(request):
     return int(request.config.option.size)
@@ -49,6 +67,13 @@ def pairs(size, keys):
     return {'pymemcache_test:%d' % i: 'X' * size for i in range(keys)}
 
 
+@pytest.fixture(scope='session')
+def tls_context():
+    return ssl.create_default_context(
+        cafile=os.path.join(os.path.dirname(__file__), "certs/ca-root.crt")
+    )
+
+
 def pytest_generate_tests(metafunc):
     if 'socket_module' in metafunc.fixturenames:
         socket_modules = [socket]
