@@ -193,7 +193,7 @@ class CustomizedClient(Client):
 class ClientTestMixin(object):
     def make_client(self, mock_socket_values, **kwargs):
         client = Client(None, **kwargs)
-        # mock out client._connect() rather than hard-settting client.sock to
+        # mock out client._connect() rather than hard-setting client.sock to
         # ensure methods are checking whether self.sock is None before
         # attempting to use it
         sock = MockSocket(list(mock_socket_values))
@@ -203,7 +203,7 @@ class ClientTestMixin(object):
 
     def make_customized_client(self, mock_socket_values, **kwargs):
         client = CustomizedClient(None, **kwargs)
-        # mock out client._connect() rather than hard-settting client.sock to
+        # mock out client._connect() rather than hard-setting client.sock to
         # ensure methods are checking whether self.sock is None before
         # attempting to use it
         sock = MockSocket(list(mock_socket_values))
@@ -381,6 +381,16 @@ class ClientTestMixin(object):
         result = client.get(b'key', default='foobar')
         assert result == 'foobar'
 
+    def test_get_ignore_exc_default(self):
+        client = self.make_client([b'INVALID DATA\r\n'], ignore_exc=True)
+        result = client.get(b'key', default='foobar')
+        assert result == 'foobar'
+
+        # Unit test for customized client (override _extract_value)
+        client = self.make_client([b'INVALID DATA\r\n'], ignore_exc=True)
+        result = client.get(b'key', default='foobar')
+        assert result == 'foobar'
+
     def test_get_found(self):
         client = self.make_client([
             b'STORED\r\n',
@@ -991,6 +1001,11 @@ class TestClient(ClientTestMixin, unittest.TestCase):
         ]
         assert result == {b'fake_stats': 1}
 
+    def test_stats_with_blank_value(self):
+        client = self.make_client([b"STAT fake_stats \r\n", b"END\r\n"])
+        result = client.stats()
+        assert result == {b"fake_stats": b""}
+
     def test_stats_conversions(self):
         client = self.make_client([
             # Most stats are converted to int
